@@ -27,8 +27,9 @@ class GtkCTreeNode:
 	expanded = _
 
 class GtkStyle:
-	"""Currently you can't assign to any of the attributes of a GtkStyle"""
-	"""This type can't be instantiated directly"""
+	"""You can assign to any attribute except colormap.  Also, assigning"""
+	"""to the sequence attributes is not allowed -- only assinging to"""
+	"""sequence members."""
 
 	"""COLORS"""
 	black = _
@@ -63,6 +64,10 @@ class GtkStyle:
 	"""The colormap for this style"""
 	colormap = _
 
+	def copy(self):
+		"""take a copy of this style"""
+		pass
+
 class GtkSelectionData:
 	"""This type represents the selection.  Do not keep a reference"""
 	"""to it past the life of a callback"""
@@ -124,6 +129,12 @@ class GdkColormap:
 		that has been allocated in the colormap"""
 		pass
 
+class GdkCursor:
+	"""the type number of this cursor, or -1 for a pixmap cursor"""
+	type = _
+	"""the string name for this type of cursor"""
+	name = _
+
 class GdkDragContext:
 	"""This event holds the context of a DND drag"""
 
@@ -252,6 +263,9 @@ class GdkGC:
 	line_style = _
 	cap_style = _
 	join_style = _
+	def set_dashes(self, dash_offset, dash_list):
+		"""set the dash pattern for this GC."""
+		pass
 
 class GdkWindow:
 	"""All attributes are read only for GdkWindow's"""
